emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 069e0ba9f3: Fix URL-related typos in comments and messages


From: Lars Ingebrigtsen
Subject: master 069e0ba9f3: Fix URL-related typos in comments and messages
Date: Wed, 6 Apr 2022 03:28:00 -0400 (EDT)

branch: master
commit 069e0ba9f3aa21c29a6b3a35f63a440c3ca9c8ab
Author: Lars Ingebrigtsen <larsi@gnus.org>
Commit: Lars Ingebrigtsen <larsi@gnus.org>

    Fix URL-related typos in comments and messages
    
    * lisp/ffap.el (ffap-next): Fix typo in message.
    * lisp/finder.el (finder-commentary): Fix typo in comment.
---
 lisp/ffap.el   | 8 ++++----
 lisp/finder.el | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/finder.el b/lisp/finder.el
index a40f8c64f2..899e829296 100644
--- a/lisp/finder.el
+++ b/lisp/finder.el
@@ -367,7 +367,7 @@ not `finder-known-keywords'."
   "Display FILE's commentary section.
 FILE should be in a form suitable for passing to `locate-library'."
   ;; FIXME: Merge this function into `describe-package', which is
-  ;; strictly better as it has links to URL's and is in a proper help
+  ;; strictly better as it has links to URLs and is in a proper help
   ;; buffer with navigation forward and backward, etc.
   (interactive
    (list



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/ffap.el b/lisp/ffap.el
index b5d2a02cd1..30a9577d38 100644
--- a/lisp/ffap.el
+++ b/lisp/ffap.el
@@ -79,7 +79,7 @@
 ;; (setq ffap-shell-prompt-regexp nil)  ; disable shell prompt stripping
 ;; (setq ffap-gopher-regexp nil)        ; disable gopher bookmark matching
 ;;
 ;; ffap uses `browse-url' (if found, else `w3-fetch') to fetch URL's.
 ;; For a hairier `ffap-url-fetcher', try ffap-url.el (same ftp site).
 ;; Also, you can add `ffap-menu-rescan' to various hooks to fontify
 ;; the file and URL references within a buffer.
@@ -282,7 +282,7 @@ For a fancy alternative, get `ffap-url.el'."
   :risky t)
 
 (defcustom ffap-next-regexp
   ;; If you want ffap-next to find URL's only, try this:
   ;; (and ffap-url-regexp (string-match "\\\\`" ffap-url-regexp)
   ;;     (concat "\\<" (substring ffap-url-regexp 2))))
   ;;
@@ -315,7 +315,7 @@ disable ffap most of the time."
 
 ;;; Find Next Thing in buffer (`ffap-next'):
 ;;
 ;; Original ffap-next-url (URL's only) from RPECK 30 Mar 1995.  Since
 ;; then, broke it up into ffap-next-guess (noninteractive) and
 ;; ffap-next (a command).  It now work on files as well as url's.
 
@@ -363,7 +363,7 @@ Actual search is done by the function `ffap-next-guess'."
          (sit-for 0)                   ; display point movement
          (find-file-at-point (ffap-prompter guess)))
       (goto-char pt)                   ; restore point
-      (message "No %sfiles or URL's found"
+      (message "No %sfiles or URLs found"
               (if wrap "" "more ")))))
 
 (defun ffap-next-url (&optional back wrap)
@@ -79,7 +79,7 @@
 ;; (setq ffap-gopher-regexp nil)        ; disable gopher bookmark matching
 ;;
-;; ffap uses `browse-url' (if found, else `w3-fetch') to fetch URL's.
+;; ffap uses `browse-url' (if found, else `w3-fetch') to fetch URLs.
 ;; For a hairier `ffap-url-fetcher', try ffap-url.el (same ftp site).
 ;; Also, you can add `ffap-menu-rescan' to various hooks to fontify
@@ -282,7 +282,7 @@ For a fancy alternative, get `ffap-url.el'."
 
 (defcustom ffap-next-regexp
-  ;; If you want ffap-next to find URL's only, try this:
+  ;; If you want ffap-next to find URLs only, try this:
   ;; (and ffap-url-regexp (string-match "\\\\`" ffap-url-regexp)
   ;;     (concat "\\<" (substring ffap-url-regexp 2))))
@@ -315,7 +315,7 @@ disable ffap most of the time."
 ;;; Find Next Thing in buffer (`ffap-next'):
 ;;
-;; Original ffap-next-url (URL's only) from RPECK 30 Mar 1995.  Since
+;; Original ffap-next-url (URLs only) from RPECK 30 Mar 1995.  Since
 ;; then, broke it up into ffap-next-guess (noninteractive) and
 ;; ffap-next (a command).  It now work on files as well as url's.